ChangeReason

Enum ChangeReason 

#[repr(u8)]
pub enum ChangeReason { Unknown = 0, Success = 1, Failure = 2, Timeout = 3, Delaybyprovider = 4, }

Variants



Unknown = 0

The reason for a state change is unknown.



Success = 1

The reason for a state change is the success of a prior operation.



Failure = 2

The reason for a state change is the failure of a prior operation.



Timeout = 3

The reason for a state change is a time-out.



Delaybyprovider = 4

The reason for a state change is a request by the OTA Provider to wait.

Implementations

Source

impl ChangeReason

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value