#[repr(u8)]pub enum UpdateState {
Unknown = 0,
Idle = 1,
Querying = 2,
Delayedonquery = 3,
Downloading = 4,
Applying = 5,
Delayedonapply = 6,
Rollingback = 7,
Delayedonuserconsent = 8,
}Variants
Unknown = 0
Current state is not yet determined.
Idle = 1
Indicate a Node not yet in the process of software update.
Querying = 2
Indicate a Node in the process of querying an OTA Provider.
Delayedonquery = 3
Indicate a Node waiting after a Busy response.
Downloading = 4
Indicate a Node currently in the process of downloading a software update.
Applying = 5
Indicate a Node currently in the process of verifying and applying a software update.
Delayedonapply = 6
Indicate a Node waiting caused by AwaitNextAction response.
Rollingback = 7
Indicate a Node in the process of recovering to a previous version.
Delayedonuserconsent = 8
Indicate a Node is capable of user consent.
Implementations